pub struct RawCallResult<FEN: FoundryEvmNetwork = EthEvmNetwork> {Show 20 fields
pub exit_reason: Option<InstructionResult>,
pub reverted: bool,
pub has_state_snapshot_failure: bool,
pub result: Bytes,
pub gas_used: u64,
pub gas_refunded: u64,
pub stipend: u64,
pub logs: Vec<Log>,
pub labels: AddressHashMap<String>,
pub traces: Option<SparsedTraceArena>,
pub line_coverage: Option<HitMaps>,
pub edge_coverage: Option<Vec<u8>>,
pub transactions: Option<BroadcastableTransactions<FEN::Network>>,
pub state_changeset: StateChangeset,
pub evm_env: EvmEnvFor<FEN>,
pub tx_env: TxEnvFor<FEN>,
pub cheatcodes: Option<Box<Cheatcodes<FEN>>>,
pub out: Option<Output>,
pub chisel_state: Option<(Vec<U256>, Vec<u8>)>,
pub reverter: Option<Address>,
}Expand description
The result of a raw call.
Fields
exit_reason: Option<InstructionResult>The status of the call
reverted: boolWhether the call reverted or not
has_state_snapshot_failure: boolWhether the call includes a snapshot failure
This is tracked separately from revert because a snapshot failure can occur without a revert, since assert failures are stored in a global variable (ds-test legacy)
result: BytesThe raw result of the call.
gas_used: u64The gas used for the call
gas_refunded: u64Refunded gas
stipend: u64The initial gas stipend for the transaction
logs: Vec<Log>The logs emitted during the call
labels: AddressHashMap<String>The labels assigned to addresses during the call
traces: Option<SparsedTraceArena>The traces of the call
line_coverage: Option<HitMaps>The line coverage info collected during the call
edge_coverage: Option<Vec<u8>>The edge coverage info collected during the call
transactions: Option<BroadcastableTransactions<FEN::Network>>Scripted transactions generated from this call
state_changeset: StateChangesetThe changeset of the state.
evm_env: EvmEnvFor<FEN>The EvmEnv after the call
tx_env: TxEnvFor<FEN>The TxEnv after the call
cheatcodes: Option<Box<Cheatcodes<FEN>>>The cheatcode states after execution
out: Option<Output>The raw output of the execution
chisel_state: Option<(Vec<U256>, Vec<u8>)>The chisel state
reverter: Option<Address>Implementations
Sourceimpl<FEN: FoundryEvmNetwork> RawCallResult<FEN>
impl<FEN: FoundryEvmNetwork> RawCallResult<FEN>
Sourcepub fn from_evm_result(
r: Result<Self, EvmError<FEN>>,
) -> Result<(Self, Option<String>)>
pub fn from_evm_result( r: Result<Self, EvmError<FEN>>, ) -> Result<(Self, Option<String>)>
Unpacks an EVM result.
Sourcepub fn into_evm_error(self, rd: Option<&RevertDecoder>) -> EvmError<FEN>
pub fn into_evm_error(self, rd: Option<&RevertDecoder>) -> EvmError<FEN>
Converts the result of the call into an EvmError.
Sourcepub fn into_execution_error(self, reason: String) -> ExecutionErr<FEN>
pub fn into_execution_error(self, reason: String) -> ExecutionErr<FEN>
Converts the result of the call into an ExecutionErr.
Sourcepub fn into_result(
self,
rd: Option<&RevertDecoder>,
) -> Result<Self, EvmError<FEN>>
pub fn into_result( self, rd: Option<&RevertDecoder>, ) -> Result<Self, EvmError<FEN>>
Returns an EvmError if the call failed, otherwise returns self.
Sourcepub fn into_decoded_result(
self,
func: &Function,
rd: Option<&RevertDecoder>,
) -> Result<CallResult<DynSolValue, FEN>, EvmError<FEN>>
pub fn into_decoded_result( self, func: &Function, rd: Option<&RevertDecoder>, ) -> Result<CallResult<DynSolValue, FEN>, EvmError<FEN>>
Decodes the result of the call with the given function.
Sourcepub fn transactions(&self) -> Option<&BroadcastableTransactions<FEN::Network>>
pub fn transactions(&self) -> Option<&BroadcastableTransactions<FEN::Network>>
Returns the transactions generated from this call.
Sourcepub fn merge_edge_coverage(&mut self, history_map: &mut [u8]) -> (bool, bool)
pub fn merge_edge_coverage(&mut self, history_map: &mut [u8]) -> (bool, bool)
Update provided history map with edge coverage info collected during this call. Uses AFL binning algo https://github.com/h0mbre/Lucid/blob/3026e7323c52b30b3cf12563954ac1eaa9c6981e/src/coverage.rs#L57-L85